[Libreoffice-commits] core.git: writerfilter/source

Michael Stahl (via logerrit) logerrit at kemper.freedesktop.org
Thu Jan 9 14:52:47 UTC 2020


 writerfilter/source/dmapper/DomainMapper_Impl.cxx |   18 +++++++++---------
 writerfilter/source/dmapper/DomainMapper_Impl.hxx |    2 +-
 2 files changed, 10 insertions(+), 10 deletions(-)

New commits:
commit 0333a52975ca60d6ea953a465d1f70fb5b9b8d96
Author:     Michael Stahl <Michael.Stahl at cib.de>
AuthorDate: Wed Jan 8 18:03:20 2020 +0100
Commit:     Michael Stahl <michael.stahl at cib.de>
CommitDate: Thu Jan 9 15:52:14 2020 +0100

    writerfilter: fix confusing typo, it's SDT (structured document tag)
    
    Change-Id: I70f8fa752ddac936de6d9f272eff8d36b83858a9
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/86445
    Tested-by: Jenkins
    Reviewed-by: Michael Stahl <michael.stahl at cib.de>

diff --git a/writerfilter/source/dmapper/DomainMapper_Impl.hxx b/writerfilter/source/dmapper/DomainMapper_Impl.hxx
index 2691bbf659d6..6340b2da34d0 100644
--- a/writerfilter/source/dmapper/DomainMapper_Impl.hxx
+++ b/writerfilter/source/dmapper/DomainMapper_Impl.hxx
@@ -584,7 +584,7 @@ private:
     SmartTagHandler m_aSmartTagHandler;
 
     css::uno::Reference<css::text::XTextRange> m_xGlossaryEntryStart;
-    css::uno::Reference<css::text::XTextRange> m_xStdEntryStart;
+    css::uno::Reference<css::text::XTextRange> m_xSdtEntryStart;
 
 public:
     css::uno::Reference<css::text::XTextRange> m_xInsertTextRange;


More information about the Libreoffice-commits mailing list
diff --git a/writerfilter/source/dmapper/DomainMapper_Impl.cxx b/writerfilter/source/dmapper/DomainMapper_Impl.cxx
index 7c4cc46dba31..3837872d5b1d 100644
--- a/writerfilter/source/dmapper/DomainMapper_Impl.cxx
+++ b/writerfilter/source/dmapper/DomainMapper_Impl.cxx
@@ -607,11 +607,11 @@ void DomainMapper_Impl::SetSdt(bool bSdt)
 
     if (m_bSdt && !m_aTextAppendStack.empty())
     {
-        m_xStdEntryStart = GetTopTextAppend()->getEnd();
+        m_xSdtEntryStart = GetTopTextAppend()->getEnd();
     }
     else
     {
-        m_xStdEntryStart = uno::Reference< text::XTextRange >();
+        m_xSdtEntryStart.clear();
     }
 }
 
@@ -4119,7 +4119,7 @@ static uno::Sequence< beans::PropertyValues > lcl_createTOXLevelHyperlinks( bool
 /// Returns title of the TOC placed in paragraph(s) before TOC field inside STD-frame
 OUString DomainMapper_Impl::extractTocTitle()
 {
-    if (!m_xStdEntryStart.is())
+    if (!m_xSdtEntryStart.is())
         return OUString();
 
     uno::Reference< text::XTextAppend > xTextAppend = m_aTextAppendStack.top().xTextAppend;
@@ -4129,7 +4129,7 @@ OUString DomainMapper_Impl::extractTocTitle()
     // try-catch was added in the same way as inside appendTextSectionAfter()
     try
     {
-        uno::Reference< text::XParagraphCursor > xCursor( xTextAppend->createTextCursorByRange( m_xStdEntryStart ), uno::UNO_QUERY_THROW);
+        uno::Reference<text::XParagraphCursor> xCursor(xTextAppend->createTextCursorByRange(m_xSdtEntryStart), uno::UNO_QUERY_THROW);
         if (!xCursor.is())
             return OUString();
 
@@ -4315,7 +4315,7 @@ void DomainMapper_Impl::handleToc
         if (aTocTitle.isEmpty() || bTableOfFigures)
         {
             // reset marker of the TOC title
-            m_xStdEntryStart.clear();
+            m_xSdtEntryStart.clear();
 
             // Create section before setting m_bStartTOC: finishing paragraph
             // inside StartIndexSectionChecked could do the wrong thing otherwise
@@ -4331,7 +4331,7 @@ void DomainMapper_Impl::handleToc
         {
             // create TOC section
             css::uno::Reference<css::text::XTextRange> xTextRangeEndOfTocHeader = GetTopTextAppend()->getEnd();
-            xTOC = createSectionForRange(m_xStdEntryStart, xTextRangeEndOfTocHeader, sTOCServiceName, false);
+            xTOC = createSectionForRange(m_xSdtEntryStart, xTextRangeEndOfTocHeader, sTOCServiceName, false);
 
             // init [xTOCMarkerCursor]
             uno::Reference< text::XText > xText = xTextAppend->getText();
@@ -4340,7 +4340,7 @@ void DomainMapper_Impl::handleToc
 
             // create header of the TOC with the TOC title inside
             const OUString aObjectType("com.sun.star.text.IndexHeaderSection");
-            uno::Reference<beans::XPropertySet> xIfc = createSectionForRange(m_xStdEntryStart, xTextRangeEndOfTocHeader, aObjectType, true);
+            uno::Reference<beans::XPropertySet> xIfc = createSectionForRange(m_xSdtEntryStart, xTextRangeEndOfTocHeader, aObjectType, true);
         }
     }
 
@@ -5675,8 +5675,8 @@ void DomainMapper_Impl::PopFieldContext()
                 {
                     if (m_bStartedTOC || m_bStartIndex || m_bStartBibliography)
                     {
-                        // inside Std, last empty paragraph is also part of index
-                        if (!m_bParaChanged && !m_xStdEntryStart)
+                        // inside SDT, last empty paragraph is also part of index
+                        if (!m_bParaChanged && !m_xSdtEntryStart)
                         {
                             // End of index is the first item on a new paragraph - this paragraph
                             // should not be part of index